@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.0.0";
+our $VERSION = "v6.0.1";
 
 1;
 __END__
@@ -49,7 +49,7 @@ RxPerl - an implementation of Reactive Extensions / rxjs for Perl
 You probably want to install one of the three adapter modules for your project instead of this one:
 L<RxPerl::AnyEvent>, L<RxPerl::IOAsync> or L<RxPerl::Mojo>.
 
-Each of these three modules adapt RxPerl to one of three event interfaces available in Perl (L<AnyEvent>,
+Each of these three modules adapts RxPerl to one of three event interfaces available in Perl (L<AnyEvent>,
 L<IO::Async> and L<Mojo::IOLoop>), so pick the one that corresponds to the event interface that your app uses.
 
 The documentation in this POD applies to all three adapter modules as well.
@@ -509,6 +509,27 @@ L<https://rxjs.dev/api/operators/pluck>
 
 L<https://rxjs.dev/api/operators/refCount>
 
+=item op_repeat
+
+L<https://rxjs.dev/api/operators/repeat>
+
+    # 10, 20, 30, 10, 20, 30, 10, 20, 30, complete
+    rx_of(10, 20, 30)->pipe(
+        op_repeat(3),
+    )->subscribe($observer);
+
+=item op_retry
+
+L<https://rxjs.dev/api/operators/retry>
+
+    # 10, 20, 30, 10, 20, 30, 10, 20, 30, error: foo
+    rx_concat(
+        rx_of(10, 20, 30),
+        rx_throw_error('foo'),
+    )->pipe(
+        op_repeat(2),
+    )->subscribe($observer);
+
 =item op_sample_time
 
 L<https://rxjs.dev/api/operators/sampleTime>
@@ -545,6 +566,15 @@ L<https://rxjs.dev/api/operators/share>
     $o->subscribe($observer1);
     $o->subscribe($observer2);
 
+=item op_skip
+
+L<https://rxjs.dev/api/operators/skip>
+
+    # 40, 50, complete
+    rx_of(10, 20, 30, 40, 50)->pipe(
+        op_skip(3),
+    )->subscribe($observer);
+
 =item op_start_with
 
 L<https://rxjs.dev/api/operators/startWith>
